import * as util from 'util';

var originalLog = console.log;
var originalWarn = console.warn;
var originalError = console.error;

var prefix = '';

function format ( args ) {
	return util.format.apply( util, args ).replace( /^/gm, prefix );
}

function consoleLog () {
	this._stdout.write( format( arguments ) + '\n' );
}

function consoleError () {
	this._stderr.write( format( arguments ) + '\n' );
}

function consoleGroup () {
	prefix += '⎢ ';
	this._stdout.write( '\u001b[1m' + format( arguments ) + '\u001b[22m\n' );
}

function consoleGroupEnd () {
	prefix = prefix.slice( 0, -2 );
}

function install () {
	console.log = consoleLog;
	console.warn = console.error = consoleError;
	console.group = consoleGroup;
	console.groupEnd = consoleGroupEnd;
}

function teardown () {
	console.log = originalLog;
	console.warn = originalWarn;
	console.error = originalError;
	delete console.group;
	delete console.groupEnd;
}

export { install, teardown };